type Account = {
    accountId: string;
    isDefault: string;
    accountName: string;
    baseUri: string;
    organization: string;
};

type DocuSignToken = {
    authToken: OAuthToken;
    account: Account;
};
type OAuthToken = {
    access_token: string;
    data: any;
    expires_in: string;
    refresh_token: string;
    scope: string;
    token_type: string;
};

declare const DsConfig: {
    dsClientId: string;
    impersonatedUserGuid: string;
    appUrl: string;
    authUrl: string;
    production: boolean;
    baseAccountUri: string;
    baseAuthUri: string;
    dsUserEmail: string;
    middlewareKey: string;
};

declare class DsJwtAuth {
    dsConfig: typeof DsConfig;
    constructor(_dsConfig: typeof DsConfig);
    authenticate: () => Promise<DocuSignToken>;
    getUserInfo: (authToken: string) => Promise<any>;
}

interface EnvelopeDefinition {
    emailSubject?: string;
    emailBlurb?: string;
    status?: EnvelopeStatus;
    recipients?: any;
    carbonCopies?: any;
    documents?: EnvelopeDocument[];
    customFields?: CustomFields;
}
type EnvelopeDocument = {
    name: string;
    fileExtension: string;
    documentId: string;
    documentBase64: any;
    documentFields: any;
};
declare enum EnvelopeStatus {
    sent = "sent",
    created = "created",
    completed = "completed"
}
type CustomFields = {
    textCustomFields?: TextCustomFields[];
    listCustomFields?: ListCustomFields[];
};
type TextCustomFields = {
    fieldId?: string;
    name?: string;
    show?: boolean;
    required?: boolean;
    value?: string;
    configurationType?: string;
    errorDetails?: {
        errorCode?: string;
        message?: string;
    };
};
type ListCustomFields = {
    listItems: string[];
    fieldId?: string;
    name?: string;
    show?: boolean;
    required?: boolean;
    value?: string;
    configurationType?: string;
    errorDetails?: {
        errorCode?: string;
        message?: string;
    };
};

declare class Envelope {
    dsConfig: typeof DsConfig;
    constructor(_dsConfig: typeof DsConfig);
    private docusignAuthenticate;
    sendEnvelopeFromFileUrl(fileUrl: string[], envelopeDef: EnvelopeDefinition): Promise<any>;
    sendEnvelope(fileBlobList: FileList, envelopeDef: EnvelopeDefinition): Promise<any>;
    private getFileAsBase64FromFileBlob;
    private getFileAsBase64FromUrl;
}

export { type CustomFields, DsJwtAuth, Envelope, type EnvelopeDefinition, type EnvelopeDocument, EnvelopeStatus, type ListCustomFields, type TextCustomFields };
