"use strict";
var __create = Object.create;
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __getProtoOf = Object.getPrototypeOf;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toESM = (mod, isNodeMode, target) => (target = mod != null ? __create(__getProtoOf(mod)) : {}, __copyProps(
  // If the importer is in node compatibility mode or this is not an ESM
  // file that has been converted to a CommonJS file using a Babel-
  // compatible transform (i.e. "__esModule" has not been set), then set
  // "default" to the CommonJS "module.exports" for node compatibility.
  isNodeMode || !mod || !mod.__esModule ? __defProp(target, "default", { value: mod, enumerable: true }) : target,
  mod
));
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);

// src/index.ts
var src_exports = {};
__export(src_exports, {
  DsJwtAuth: () => DsJwtAuth,
  Envelope: () => Envelope,
  EnvelopeStatus: () => EnvelopeStatus
});
module.exports = __toCommonJS(src_exports);

// src/config/dsConfig.json
var dsConfig_default = {
  dsClientId: "",
  impersonatedUserGuid: "",
  appUrl: "",
  authUrl: "",
  production: false,
  baseAccountUri: "",
  baseAuthUri: "",
  dsUserEmail: "",
  middlewareKey: ""
};

// src/dsConfig.ts
var DsConfig = {
  ...dsConfig_default
};

// src/oAuth/dsJwtAuth.ts
var import_axios = __toESM(require("axios"));
var DsJwtAuth = class {
  dsConfig = DsConfig;
  constructor(_dsConfig) {
    this.dsConfig = _dsConfig;
  }
  authenticate = async () => {
    const reqUrl = this.dsConfig.dsUserEmail ? `${this.dsConfig.authUrl}?docuSignUserEmail=${this.dsConfig.dsUserEmail}` : this.dsConfig.authUrl;
    const authResponse = await import_axios.default.get(reqUrl, {
      headers: {
        "X-Middleware-Key": this.dsConfig.middlewareKey
      }
    }).then();
    const authResult = authResponse && authResponse.status == 200 && await authResponse.data;
    return authResult;
  };
  getUserInfo = async (authToken) => {
    const url = `${this.dsConfig.baseAuthUri}/oauth/userinfo`;
    let response = await import_axios.default.get(url, {
      headers: {
        Authorization: `Bearer ${authToken}`,
        Accept: `application/json`,
        "Content-Type": "application/json"
      }
    });
    const userResult = response && response.status == 200 && await response.data;
    return userResult;
  };
};

// src/envelope/envelope.ts
var import_axios2 = __toESM(require("axios"));

// src/envelope/envelopeDef.ts
var EnvelopeStatus = /* @__PURE__ */ ((EnvelopeStatus2) => {
  EnvelopeStatus2["sent"] = "sent";
  EnvelopeStatus2["created"] = "created";
  EnvelopeStatus2["completed"] = "completed";
  return EnvelopeStatus2;
})(EnvelopeStatus || {});

// src/envelope/envelope.ts
var urlFrag = "/restapi/v2.1";
var Envelope = class {
  dsConfig = DsConfig;
  constructor(_dsConfig) {
    this.dsConfig = _dsConfig;
  }
  docusignAuthenticate = async () => {
    const docusignAuth = new DsJwtAuth(this.dsConfig);
    const authResult = await docusignAuth.authenticate();
    return authResult;
  };
  async sendEnvelopeFromFileUrl(fileUrl, envelopeDef) {
    try {
      let envelopeDocuments = [];
      for (let i = 0; i < fileUrl.length; i++) {
        const file = fileUrl[i];
        const fileName = file.substring(file.lastIndexOf("/") + 1);
        const fileExt = fileName.split(".").pop() ?? "";
        const file64 = await this.getFileAsBase64FromUrl(file);
        const document = {
          name: fileName,
          fileExtension: fileExt,
          documentId: String(i + 1),
          documentBase64: file64,
          documentFields: null
        };
        envelopeDocuments.push(document);
      }
      if (envelopeDocuments.length == 0)
        throw new Error("no documents to attach, please attach atleast one document.");
      envelopeDef.documents = envelopeDocuments;
      const authResult = await this.docusignAuthenticate();
      const url = `${authResult.account.baseUri}${urlFrag}/accounts/${authResult.account.accountId}/envelopes`;
      const response = await import_axios2.default.post(url, JSON.stringify(envelopeDef), {
        headers: {
          Authorization: `Bearer ${authResult.authToken.access_token}`,
          Accept: `application/json`,
          "Content-Type": "application/json"
        }
      });
      const envelopeResult = response && response.status == 201 && await response.data;
      return envelopeResult;
    } catch (e) {
      console.log(`error: ${e}`);
    }
  }
  async sendEnvelope(fileBlobList, envelopeDef) {
    try {
      let envelopeDocuments = [];
      for (let i = 0; i < fileBlobList.length; i++) {
        const file = fileBlobList[i];
        const fileName = file.name;
        const fileExt = fileName.split(".").pop() ?? "";
        const file64 = await this.getFileAsBase64FromFileBlob(file);
        const document = {
          name: fileName,
          fileExtension: fileExt,
          documentId: String(i + 1),
          documentBase64: file64,
          documentFields: null
        };
        envelopeDocuments.push(document);
      }
      if (envelopeDocuments.length == 0)
        throw new Error("no documents to attach, please attach atleast one document.");
      envelopeDef.documents = envelopeDocuments;
      const authResult = await this.docusignAuthenticate();
      const url = `${authResult.account.baseUri}${urlFrag}/accounts/${authResult.account.accountId}/envelopes`;
      const response = await import_axios2.default.post(url, JSON.stringify(envelopeDef), {
        headers: {
          Authorization: `Bearer ${authResult.authToken.access_token}`,
          Accept: `application/json`,
          "Content-Type": "application/json"
        }
      });
      const envelopeResult = response && response.status == 201 && await response.data;
      return envelopeResult;
    } catch (e) {
      console.log(`error: ${e}`);
    }
  }
  getFileAsBase64FromFileBlob = async (fileBlob) => {
    const reader = new FileReader();
    await new Promise((resolve) => {
      reader.onloadend = resolve;
      reader.readAsDataURL(fileBlob);
    });
    const base64File = reader?.result?.toString().split(",")[1];
    return base64File;
  };
  getFileAsBase64FromUrl = async (fileUrl) => {
    let response = await fetch(fileUrl);
    if (!response || response.status !== 200) {
      const msg = `Could not fetch file ${fileUrl}`;
      console.log(msg);
      return;
    }
    const fileBlob = await response.blob();
    const reader = new FileReader();
    await new Promise((resolve) => {
      reader.onloadend = resolve;
      reader.readAsDataURL(fileBlob);
    });
    const base64File = reader?.result?.toString().split(",")[1];
    return base64File;
  };
};
// Annotate the CommonJS export names for ESM import in node:
0 && (module.exports = {
  DsJwtAuth,
  Envelope,
  EnvelopeStatus
});
