// src/config/dsConfig.json
var dsConfig_default = {
  dsClientId: "",
  impersonatedUserGuid: "",
  appUrl: "",
  authUrl: "",
  production: false,
  baseAccountUri: "",
  baseAuthUri: "",
  dsUserEmail: "",
  middlewareKey: ""
};

// src/dsConfig.ts
var DsConfig = {
  ...dsConfig_default
};

// src/oAuth/dsJwtAuth.ts
import axios from "axios";
var DsJwtAuth = class {
  dsConfig = DsConfig;
  constructor(_dsConfig) {
    this.dsConfig = _dsConfig;
  }
  authenticate = async () => {
    const reqUrl = this.dsConfig.dsUserEmail ? `${this.dsConfig.authUrl}?docuSignUserEmail=${this.dsConfig.dsUserEmail}` : this.dsConfig.authUrl;
    const authResponse = await axios.get(reqUrl, {
      headers: {
        "X-Middleware-Key": this.dsConfig.middlewareKey
      }
    }).then();
    const authResult = authResponse && authResponse.status == 200 && await authResponse.data;
    return authResult;
  };
  getUserInfo = async (authToken) => {
    const url = `${this.dsConfig.baseAuthUri}/oauth/userinfo`;
    let response = await axios.get(url, {
      headers: {
        Authorization: `Bearer ${authToken}`,
        Accept: `application/json`,
        "Content-Type": "application/json"
      }
    });
    const userResult = response && response.status == 200 && await response.data;
    return userResult;
  };
};

// src/envelope/envelope.ts
import axios2 from "axios";

// src/envelope/envelopeDef.ts
var EnvelopeStatus = /* @__PURE__ */ ((EnvelopeStatus2) => {
  EnvelopeStatus2["sent"] = "sent";
  EnvelopeStatus2["created"] = "created";
  EnvelopeStatus2["completed"] = "completed";
  return EnvelopeStatus2;
})(EnvelopeStatus || {});

// src/envelope/envelope.ts
var urlFrag = "/restapi/v2.1";
var Envelope = class {
  dsConfig = DsConfig;
  constructor(_dsConfig) {
    this.dsConfig = _dsConfig;
  }
  docusignAuthenticate = async () => {
    const docusignAuth = new DsJwtAuth(this.dsConfig);
    const authResult = await docusignAuth.authenticate();
    return authResult;
  };
  async sendEnvelopeFromFileUrl(fileUrl, envelopeDef) {
    try {
      let envelopeDocuments = [];
      for (let i = 0; i < fileUrl.length; i++) {
        const file = fileUrl[i];
        const fileName = file.substring(file.lastIndexOf("/") + 1);
        const fileExt = fileName.split(".").pop() ?? "";
        const file64 = await this.getFileAsBase64FromUrl(file);
        const document = {
          name: fileName,
          fileExtension: fileExt,
          documentId: String(i + 1),
          documentBase64: file64,
          documentFields: null
        };
        envelopeDocuments.push(document);
      }
      if (envelopeDocuments.length == 0)
        throw new Error("no documents to attach, please attach atleast one document.");
      envelopeDef.documents = envelopeDocuments;
      const authResult = await this.docusignAuthenticate();
      const url = `${authResult.account.baseUri}${urlFrag}/accounts/${authResult.account.accountId}/envelopes`;
      const response = await axios2.post(url, JSON.stringify(envelopeDef), {
        headers: {
          Authorization: `Bearer ${authResult.authToken.access_token}`,
          Accept: `application/json`,
          "Content-Type": "application/json"
        }
      });
      const envelopeResult = response && response.status == 201 && await response.data;
      return envelopeResult;
    } catch (e) {
      console.log(`error: ${e}`);
    }
  }
  async sendEnvelope(fileBlobList, envelopeDef) {
    try {
      let envelopeDocuments = [];
      for (let i = 0; i < fileBlobList.length; i++) {
        const file = fileBlobList[i];
        const fileName = file.name;
        const fileExt = fileName.split(".").pop() ?? "";
        const file64 = await this.getFileAsBase64FromFileBlob(file);
        const document = {
          name: fileName,
          fileExtension: fileExt,
          documentId: String(i + 1),
          documentBase64: file64,
          documentFields: null
        };
        envelopeDocuments.push(document);
      }
      if (envelopeDocuments.length == 0)
        throw new Error("no documents to attach, please attach atleast one document.");
      envelopeDef.documents = envelopeDocuments;
      const authResult = await this.docusignAuthenticate();
      const url = `${authResult.account.baseUri}${urlFrag}/accounts/${authResult.account.accountId}/envelopes`;
      const response = await axios2.post(url, JSON.stringify(envelopeDef), {
        headers: {
          Authorization: `Bearer ${authResult.authToken.access_token}`,
          Accept: `application/json`,
          "Content-Type": "application/json"
        }
      });
      const envelopeResult = response && response.status == 201 && await response.data;
      return envelopeResult;
    } catch (e) {
      console.log(`error: ${e}`);
    }
  }
  getFileAsBase64FromFileBlob = async (fileBlob) => {
    const reader = new FileReader();
    await new Promise((resolve) => {
      reader.onloadend = resolve;
      reader.readAsDataURL(fileBlob);
    });
    const base64File = reader?.result?.toString().split(",")[1];
    return base64File;
  };
  getFileAsBase64FromUrl = async (fileUrl) => {
    let response = await fetch(fileUrl);
    if (!response || response.status !== 200) {
      const msg = `Could not fetch file ${fileUrl}`;
      console.log(msg);
      return;
    }
    const fileBlob = await response.blob();
    const reader = new FileReader();
    await new Promise((resolve) => {
      reader.onloadend = resolve;
      reader.readAsDataURL(fileBlob);
    });
    const base64File = reader?.result?.toString().split(",")[1];
    return base64File;
  };
};
export {
  DsJwtAuth,
  Envelope,
  EnvelopeStatus
};
